@@ -14,26 +14,11 @@
  * limitations under the License.
  */
 
-/*
-globus_i_gram_client.h
-
-CVS Information:
-    $Source: /home/globdev/CVS/globus-packages/gram/client/source/globus_i_gram_client.h,v $
-    $Date: 2007/02/27 22:10:00 $
-    $Revision: 1.5 $
-    $Author: bester $
-*/
-
 #ifndef GLOBUS_I_I_GRAM_CLIENT_INCLUDE
 #define GLOBUS_I_I_GRAM_CLIENT_INCLUDE
 
 #include "globus_gram_client.h"
 
-EXTERN_C_BEGIN
-
-/******************************************************************************
-                               Type definitions
-******************************************************************************/
 typedef struct
 {
     gss_cred_id_t                       credential;
@@ -41,6 +26,5 @@ typedef struct
 }
 globus_i_gram_client_attr_t;
 
-EXTERN_C_END
 #endif /* GLOBUS_I_I_GRAM_CLIENT_INCLUDE */
 
